-- ##########################################
-- #	John Deere 9630T Functions			#
-- #	version: 1.0						#
-- #	Date: 25.01.2017					#
-- #	author: [FSM]Chefkoch				#
-- #	hp: http://fsm-team.de				#
-- #										#
-- # 	Keine Veränderung ohne				# 
-- # 	meine Erlaubnis!					#
-- # 	No modification without				# 
-- # 	my permission!						#
-- #										#
-- #	history:							#
-- #	v1.0	Project started				#
-- #										#
-- ########################################## 	

JD9630t = {};

function JD9630t.prerequisitesPresent(specializations)
    return true;
end;

function JD9630t:load(savegame)

	-- onBoard Display Stuff
	self.speedWaitingMaxTimeHud = 3000; 
	self.speedWaitingTimerHud = 1; 
	self.hudFirst  = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.JD9630T.onBoardHud#screen1Index"));
	self.hudSecond = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.JD9630T.onBoardHud#screen2Index"));
	
	-- Indoor Sound Stuff
	self.soundAdj = {};
	local i=0;
    while true do
        local key = string.format("vehicle.indoorsoundAdjustment.animation(%d)", i);
        if not hasXMLProperty(self.xmlFile, key) then
            break;
        end;
        local animName = getXMLString(self.xmlFile, key.."#name");
        local lowpassGain = Utils.getNoNil(getXMLFloat(self.xmlFile, key.."#lowpassGain"), 0.5);
        local volumeFactor = Utils.getNoNil(getXMLFloat(self.xmlFile, key.."#volumeFactor"), 0.5);
		self.soundAdj[i] = {};
		self.soundAdj[i].animName = animName;
		self.soundAdj[i].volumeFactor = volumeFactor;
		self.soundAdj[i].lowpassGain = lowpassGain;
        i = i +1;
    end;
end;

function JD9630t:delete()
	if self.sampleOpenDoorL ~= nil then
		SoundUtil.deleteSample(self.sampleOpenDoorL);
	end;
	if self.sampleCloseDoorL ~= nil then
		SoundUtil.deleteSample(self.sampleCloseDoorL);
	end;
end;

function JD9630t:mouseEvent(posX, posY, isDown, isUp, button)
end;

function JD9630t:keyEvent(unicode, sym, modifier, isDown)
end;

function JD9630t:update(dt)

	if self.isMotorStarted then 
		if self.speedWaitingTimerHud < self.speedWaitingMaxTimeHud then 
			setVisibility(self.hudFirst, true);
			setVisibility(self.hudSecond, false);
		end;
		
		if self.speedWaitingTimerHud > 3000 then 
			setVisibility(self.hudFirst, false);
			setVisibility(self.hudSecond, true); 
		end;
		
		self.speedWaitingTimerHud = self.speedWaitingTimerHud + dt;
	else
		self.speedWaitingTimerHud = 1;
		setVisibility(self.hudFirst, false);
		setVisibility(self.hudSecond, false); 
	end;


    if self:getIsActive() and self.isClient then
		if self.isEntered then
			local sound=false;
			for i=0, #self.soundAdj do
				if self.animations[self.soundAdj[i].animName] ~= nil and self.animations[self.soundAdj[i].animName].currentTime > 150 then
					self.sampleMotor.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotor.indoorVolumeFactor);
					self.sampleMotor.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotor.indoorLowpassGain);
					self.sampleMotorStart.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorStart.indoorVolumeFactor);
					self.sampleMotorStart.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorStart.indoorLowpassGain);
					self.sampleMotorStop.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorStop.indoorVolumeFactor);
					self.sampleMotorStop.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorStop.indoorLowpassGain);
					
					self.sampleMotorRun.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorRun.indoorVolumeFactor);
					self.sampleMotorRun.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorRun.indoorLowpassGain);
					self.sampleMotorLoad.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorLoad.indoorVolumeFactor);
					self.sampleMotorLoad.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorLoad.indoorLowpassGain);
					sound=true;
				else
					if not sound then
						self.sampleMotor.indoorVolumeFactor = 0.55;
						self.sampleMotor.indoorLowpassGain = 0.2;
						self.sampleMotorStart.indoorVolumeFactor = 0.55;
						self.sampleMotorStart.indoorLowpassGain = 0.2;
						self.sampleMotorStop.indoorVolumeFactor = 0.55;
						self.sampleMotorStop.indoorLowpassGain = 0.2;
						
						self.sampleMotorRun.indoorVolumeFactor = 0.6;
						self.sampleMotorRun.indoorLowpassGain = 0.2;
						self.sampleMotorLoad.indoorVolumeFactor = 0.6;
						self.sampleMotorLoad.indoorLowpassGain = 0.2;
					end;
				end;
			end;
			SoundUtil.onCameraSwitched(self.activeCamera.isInside);
		end;
    end;
end;

function JD9630t:updateTick(dt)
end;

function JD9630t:draw()    
end;


